import pygame
from physicsbody import PhysicsBody
from constants import DIRECTION, BULLET, WORLD, ANIMATION

class Bullet(PhysicsBody):
    def __init__(self, x, y, width, height, image, direction=DIRECTION.right):
        PhysicsBody.__init__(self, x, y, width, height, image)
        self.image = pygame.transform.scale(image, (width, height))
        self.speed = BULLET.speed
        self.damage = BULLET.damage
        self.direction = direction
        self.fire = False
        self.animation = ANIMATION.splash
        self.collided = False
        self.vspeed = -4

    def damage(self, entity):
        entity.hp -= self.damage

    def update(self):
        if self.fire:
            self.vspeed += WORLD.gravity
            if self.direction == DIRECTION.right:
                self.hspeed = self.speed
            elif self.direction == DIRECTION.left:
                self.hspeed = -self.speed
            self.move(self.hspeed, self.vspeed)
        if self.collided:
            self.vspeed = 0
            self.hspeed = 0
            self.animation.loop = False

    def draw(self, screen):
        if self.fire:
            if self.collided:
                self.animation.blit(screen, self.rect)
            else:
                screen.blit(self.image, self.rect)

    def detect_collision(self, dx, dy):
        temp_rect = pygame.Rect(self.rect)
        temp_rect.x += dx
        temp_rect.y += dy

        for sprite in self.collision_group:
            if temp_rect.colliderect(sprite.rect):
                self.collided = True
                return

        self.rect = pygame.Rect(temp_rect)


