﻿import os
import pygame
import pyganim


def load_image(file_name):
    image = os.path.join("assets", "images", file_name)
    if file_name.endswith('.jpg'):
        surface = pygame.image.load(image).convert()
    else:
        surface = pygame.image.load(image).convert_alpha()
    return surface


class SCREEN(object):
    width = 1024
    height = 480
    display = pygame.display.set_mode((width, height))


class COLOR(object):
    white = (255, 255, 255)
    black = (0, 0, 0)
    gray = (31, 31, 31)
    gray7 = (77, 77, 77)
    light_gray = (102, 102, 102)
    half_black = (128, 128, 128)
    green = (0, 196, 0)
    blue = (0, 109, 135)
    deep_rose = (204, 51, 153)
    regal_red = (204, 51, 102)
    blue_sea = (0, 149, 186)
    deep_blue = (0, 121, 150)
    desert_blue = (51, 102, 153)
    gold = (204, 153, 51)
    burnt_orange = (214, 89, 49)
    deep_yellow = (251, 200, 0)
    petal_green = (128, 190, 31)
    ice_blue = (153, 255, 255)
    red = (192, 0, 0)


class GAME(object):
    fps = 60


class STATE(object):
    menu = "menu"
    game = "game"
    nextlevel = "nextlevel"
    paused = "paused"
    countdown = "countdown"
    exit = "exit"
    splash_screen = "splashscreen"
    scorescreen = "scorescreen"
    logo = "logo"
    controls = "controls"


class WORLD(object):
    gravity = 1
    scale = 1


class PLAYER(object):
    jump = -18
    speed = 5


class BULLET(object):
    speed = 12
    damage = 1

class ASSET(object):
    player = load_image("scientist.png")
    block = load_image("block.png")
    menu = load_image("menuBG.png")
    overlay = load_image("overlay.png")
    pygame_logo = load_image("pygame_logo.png")
    bg = load_image("bg.png")
    bullet = load_image("splash0.png")
    plant = load_image("bad_plant0.png")


class ANIMATION(object):
    player_idle = pyganim.PygAnimation([(os.path.join("assets", "images", "player_idle01.png"), 0.2),
                                        (os.path.join("assets", "images", "player_idle02.png"), 0.2)])

    player_run = pyganim.PygAnimation([(os.path.join("assets", "images", "player_run01.png"), 0.05),
                                       (os.path.join("assets", "images", "player_run02.png"), 0.05),
                                       (os.path.join("assets", "images", "player_run03.png"), 0.05),
                                       (os.path.join("assets", "images", "player_run03.png"), 0.05)])

    player_run_gun = pyganim.PygAnimation([(os.path.join("assets", "images", "player_run_gun01.png"), 0.1),
                                           (os.path.join("assets", "images", "player_run_gun02.png"), 0.1),
                                           (os.path.join("assets", "images", "player_run_gun03.png"), 0.1),
                                           (os.path.join("assets", "images", "player_run_gun04.png"), 0.1)])
    plant_bad = pyganim.PygAnimation([
        (os.path.join("assets", "images", "bad_plant0.png"), 0.1),
        (os.path.join("assets", "images", "bad_plant1.png"), 0.1),
        (os.path.join("assets", "images", "bad_plant2.png"), 0.1)
    ])

    plant_green = pyganim.PygAnimation([
        (os.path.join("assets", "images", "green_plant0.png"), 0.1),
        (os.path.join("assets", "images", "green_plant1.png"), 0.1),
        (os.path.join("assets", "images", "green_plant2.png"), 0.1)
    ])

    splash = pyganim.PygAnimation([
        (os.path.join("assets", "images", "splash1.png"), 0.1),
        (os.path.join("assets", "images", "splash2.png"), 0.1),
        (os.path.join("assets", "images", "splash3.png"), 0.1)
    ])

class FONT(object):
    default = os.path.join("assets", "fonts", "tinyfont.ttf")
    hoog0553 = os.path.join("assets", "fonts", "hoog0553.ttf")
    kenpixel = os.path.join("assets", "fonts", "kenpixel_mini_square.ttf")
    kenpixel_blocks = os.path.join("assets", "fonts", "kenpixel_blocks.ttf")


class DIRECTION(object):
    left = "left"
    right = "right"


