import pygame
import os
from constants import SCREEN, ASSET, GAME, PLAYER
from player import Player
from physicsbody import PhysicsBody
from plant import Plant


class Level(object):
    def __init__(self, map_file):

        self.players = []
        self.blocks = []
        self.platforms = []

        self.block_group = pygame.sprite.Group()
        self.platform_group = pygame.sprite.Group()
        self.enemy_group = pygame.sprite.Group()
        self.display_group = pygame.sprite.Group()

        self.data = None
        self.player = None

        self.width = SCREEN.height
        self.height = SCREEN.width

        self.load_map(map_file)
        self.create_level()

    def load_map(self, file_name):
        self.data = ['................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '................................',
                     '00000000000000000000000000000000',
                     '................................']
        self.width = len(self.data[0]) * 32
        self.height = len(self.data) * 32
        self.blank = '.'

        self.player = Player(0, 0, 64, 64, ASSET.player)
        self.bg = PhysicsBody(0, 0, SCREEN.width, SCREEN.height, ASSET.bg)
        self.bg.image = pygame.transform.scale(ASSET.bg, (SCREEN.width, SCREEN.height))

    def create_level(self):
        block_image = ASSET.block

        for y in range(len(self.data)):
            for x in range(len(self.data[0])):
                if self.data[y][x] == '0':
                    level_block = PhysicsBody(x*32, y*32, 32, 32, block_image)
                    self.player.collision_group.add(level_block)

        self.plant = Plant(SCREEN.width - 64, SCREEN.height - 200, 32, 64, ASSET.plant)
        self.plant.collision_group.add(self.player.collision_group)
        self.display_group.add(self.bg)
        self.display_group.add(self.plant)

    def update(self):
        self.display_group.update()
        self.player.update()


class Stage(object):
    def __init__(self, level):
        self.levels = []
        self.level_index = 0

        self.load_files()
        try:
            self.level = self.levels[level - 1]
        except:
            self.level = self.level[0]
        self.number_of_levels = len(self.levels)

    def load_files(self):
        levels = os.listdir(os.path.join("assets", "levels"))
        for level in levels:
            self.levels.append(Level(os.path.join("assets", "levels", level)))

    def load_file(self, filename):
        level = Level(os.path.join("assets", "levels", filename))
        self.levels.append(level)

    def draw(self, screen):
        for entity in self.level.display_group:
            screen.blit(entity.image, entity.rect)
        self.level.player.draw(screen)
        self.level.plant.draw(screen)

    def update(self):
        self.level.display_group.update()
