﻿import sys, os
import pygame
from pygame.locals import *
from constants import COLOR, SCREEN, STATE
from levelfactory import Stage
from menu import Menu
from splashscreen import SplashScreen
from hud import Hud


class GameEngine(object):
    def __init__(self):
        pygame.mixer.init()
        self.screen = SCREEN.display
        self.fps_clock = pygame.time.Clock()
        self.ticks = 0

        self.game_music = False

        self.menu = Menu(SCREEN.width, SCREEN.height, COLOR.white)
        self.splash = SplashScreen(0, 0, SCREEN.width, SCREEN.height)
        self.stage = Stage(1)

        self.state = STATE.splash_screen
        self.fps = 60

        self.score = 0
        self.hud = Hud()

    def handle_events(self):
        for event in pygame.event.get():
            if event.type == QUIT:
                self.make_video()
                pygame.quit()
                sys.exit()
            if self.state == STATE.menu:
                self.menu.handle_events(event)
            if self.state == STATE.game:
                self.stage.level.player.handle_events(event)

    def update(self):
        if self.state == STATE.splash_screen:
            self.splash.update()
            self.state = self.splash.state
        elif self.state == STATE.game:
            self.stage.level.update()
            self.hud.update(self.score)
            if not self.game_music:
                pygame.mixer.music.load(os.path.join("assets", "music", "150413_Last_Chance_For_Survival---free_download.ogg"))
                pygame.mixer.music.play(-1)
                self.game_music = True
        elif self.state == STATE.menu:
            self.menu.update()
            self.state = self.menu.state

    def draw(self):
        self.screen.fill(COLOR.ice_blue)
        if self.state == STATE.splash_screen:
            self.splash.draw(self.screen)
        elif self.state == STATE.menu:
            self.menu.draw(self.screen)
        elif self.state == STATE.game:
            self.stage.draw(self.screen)
            self.hud.draw(self.screen)

    def run_game(self, fps):
        self.fps = fps
        running = True

        while running:
            self.handle_events()
            self.update()
            self.draw()

            pygame.display.update()

            fps_display = str(int(self.fps_clock.get_fps())) + " FPS"
            pygame.display.set_caption("Working Title -  " + fps_display)

            self.fps_clock.tick(self.fps)

    def make_video(self):
        pygame.image.save(self.screen, os.path.join("screenshots", "screen1.jpg"))
