import pygame
import os, sys
from pygame.locals import *
from constants import COLOR, SCREEN, STATE, ASSET, FONT
from physicsbody import PhysicsBody
import pygame.mixer as mixer
from fontfactory import GameText


class Menu(object):
    def __init__(self, width, height, color):
        mixer.init()

        self.width = width
        self.height = height
        self.cursor_index = 0

        self.instructions = GameText("-- Press any key to play. ESC to exit -- ")
        self.instructions.size = 24
        self.instructions.centerx = SCREEN.width/2
        self.instructions.centery = SCREEN.height - SCREEN.height/4
        self.instructions.color = COLOR.half_black
        self.instructions.isBold = True
        self.instructions.create()

        self.bg = ASSET.menu
        self.state = STATE.menu
        self.timer = 0
        self.overlay = ASSET.overlay.convert()

        self.select_sound = mixer.Sound(os.path.join("assets", "sfx", "sfx_twoTone.ogg"))
        self.select_sound.set_volume(0.5)

    def handle_events(self, event):
        self.state = STATE.menu
        if event.type == KEYDOWN:
            if event.key != K_ESCAPE:
                self.select_sound.play()
                self.state = STATE.game
            else:
                pygame.quit()
                sys.exit()

    def update(self):
        self.animate_overlay()
        self.instructions.update()

    def draw(self, screen):
        screen.blit(self.bg, (0, 0))
        if self.timer > 32:
            self.instructions.draw_to(screen)
        screen.blit(self.overlay, (0, 0))        

    def animate_overlay(self):
        if self.timer < 255:
            self.timer += 1
            self.overlay.set_alpha(255 - self.timer * 3)
