import pygame
from constants import COLOR, SCREEN, WORLD


class PhysicsBody(pygame.sprite.Sprite):
    def __init__(self, x, y, width, height, image, direction="right"):
        pygame.sprite.Sprite.__init__(self)
        self.image = image
        self.rect = self.image.get_rect()
        self.rect.x = x
        self.rect.y = y
        self.rect.width = width * WORLD.scale
        self.rect.height = height * WORLD.scale
        self.vspeed = 0
        self.hspeed = 0
        self.gravity = WORLD.gravity
        self.grounded = True
        self.friction = 0

        self.collision_group = pygame.sprite.Group()

    def handle_events(self, events):
        pass

    def update(self):
        self.move(self.hspeed, self.vspeed)
        self.check_bounds()

    def draw(self, screen):
        screen.blit(self.image, self.rect)

    def move(self, dx, dy):
        if dx != 0:
            self.detect_collision(dx, 0)
        if dy != 0:
            self.detect_collision(0, dy)

    def check_bounds(self):
        if self.rect.left < 0:
            self.rect.left = 0

        elif self.rect.right > SCREEN.width:
            self.rect.right = SCREEN.width
        
        self.hspeed = 0

    def detect_collision(self, dx, dy):
        temp_rect = pygame.Rect(self.rect)
        temp_rect.x += dx
        temp_rect.y += dy

        for sprite in self.collision_group:
            if temp_rect.colliderect(sprite.rect):
                self.rect.x += sprite.hspeed
                if dx > 0 and sprite.vspeed == 0:
                    self.rect.right = sprite.rect.left
                elif dx < 0 and sprite.vspeed == 0:
                    self.rect.left = sprite.rect.right

                if dy > 0:
                    self.rect.bottom = sprite.rect.top
                    self.rect.y += sprite.vspeed
                    self.vspeed = 0
                    self.grounded = True
                elif dy < 0:
                    self.rect.top = sprite.rect.bottom
                    self.vspeed = 0
                return
         
        self.rect = pygame.Rect(temp_rect)