import pygame
from physicsbody import PhysicsBody
from constants import ANIMATION, SCREEN


class Plant(PhysicsBody):
    def __init__(self, x, y, width, height, image):
        PhysicsBody.__init__(self, x, y, width, height, image)

        self.animation = ANIMATION.plant_bad
        self.animation.scale((64, 64))
        self.speed = -4

    def update(self):
        self.animation.play()
        self.vspeed += self.gravity
        self.hspeed = self.speed
        if self.rect.x <= 0:
            self.hspeed = 0
        if self.rect.right >= SCREEN.width:
            self.hspeed = 0
        self.move(self.hspeed, self.vspeed)

    def draw(self, screen):
        self.animation.blit(screen, self.rect)

    def detect_collision(self, dx, dy):
        temp_rect = pygame.Rect(self.rect)
        temp_rect.x += dx
        temp_rect.y += dy

        for sprite in self.collision_group:
            if temp_rect.colliderect(sprite.rect):
                self.rect.x += sprite.hspeed
                if dx > 0 and sprite.vspeed == 0:
                    self.rect.right = sprite.rect.left
                    self.hspeed = -self.hspeed
                elif dx < 0 and sprite.vspeed == 0:
                    self.rect.left = sprite.rect.right
                    self.hspeed = -self.hspeed

                if dy > 0:
                    self.rect.bottom = sprite.rect.top
                    self.rect.y += sprite.vspeed
                    self.vspeed = 0
                    self.grounded = True
                elif dy < 0:
                    self.rect.top = sprite.rect.bottom
                    self.vspeed = 0
                return

        self.rect = pygame.Rect(temp_rect)