import pygame
from pygame.locals import *
from physicsbody import PhysicsBody
from constants import PLAYER, WORLD, DIRECTION, ANIMATION, SCREEN, ASSET, BULLET
from bullet import Bullet

IDLE = ANIMATION.player_idle  # no time to explain
RUN = ANIMATION.player_run
RUN_GUN = ANIMATION.player_run_gun


class Player(PhysicsBody):
    def __init__(self, x, y, width, height, image):
        PhysicsBody.__init__(self, x, y, width, height, image)
        self.jump_height = PLAYER.jump
        self.direction = DIRECTION.right
        self.speed = PLAYER.speed
        self.grounded = False
        self.animation = ANIMATION.player_idle
        self.animation.scale((64, 64))

        self.flipped = False
        self.bullet = Bullet(0, 0 + self.rect.height/4, 32, 32, ASSET.bullet)

    def handle_events(self, event):
        if event.type == KEYDOWN:
            if (event.key == K_i or event.key == K_SPACE) and self.grounded:
                self.vspeed = self.jump_height
                self.grounded = False
            elif event.key == K_u:
                self.animation = self.animate(RUN_GUN)
                self.shoot()
        elif event.type == KEYUP:
            if event.key == K_a or event.key == K_d or event.key == K_RIGHT or event.key == K_LEFT:
                self.hspeed = 0
                self.animation = self.animate(IDLE)
                if self.direction == DIRECTION.left:
                    self.animation.flip(True, False)

    def shoot(self):
        self.bullet.fire = True
        self.bullet.direction = self.direction
        self.bullet.speed = BULLET.speed
        self.bullet.x = self.rect.centerx
        self.bullet.y = self.rect.centery
        self.bullet.collision_group = self.collision_group.copy()

    def get_movement(self):
        key = pygame.key.get_pressed()

        if key[K_a] or key[K_LEFT]:
            self.animation = self.animate(RUN)
            self.direction = DIRECTION.left

            if self.rect.x <= 0:
                self.hspeed = 0
            else:
                self.hspeed = -self.speed
            if not self.flipped:
                self.animation.flip(True, False)
                self.flipped = True

        elif key[K_d] or key[K_RIGHT]:
            self.animation = self.animate(RUN)
            self.direction = DIRECTION.right
            self.hspeed = self.speed

            if self.rect.right >= SCREEN.width:
                self.hspeed = 0

            if self.flipped:
                self.animation.flip(True, False)
                self.flipped = False

        else:
            self.hspeed = 0

    def update(self):
        self.animation.play()
        self.vspeed += self.gravity
        self.get_movement()
        self.move(self.hspeed, self.vspeed)
        self.bullet.update()

    def draw(self, screen):
        self.animation.blit(screen, self.rect)
        self.bullet.draw(screen)

    def animate(self, frames):
        animation = frames
        animation.scale((64, 64))

        return animation

